Welcome to pydemic's documentation!
=====================================

A `python` package for modeling epidemics.


Table of Contents
-----------------

Please check :ref:`installation` to get started.

.. toctree::
    :maxdepth: 2

    ref_models
    ref_sampling
    ref_other
    installation
    changes
    license
    faq
    citing


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
